@@ -218,11 +218,11 @@ panelPal <- function(ans, panel = NULL, preprocess = FALSE,
 
     ignore <- c("xlim", "ylim", "zlim", "xlab", "ylab", "zlab", "main",
                 "at", "col.regions", "alpha.regions", "cex.range", "pch.order", 
-                "group.elements", "group.ids", "group.args", 
+                "group.elements", "group.ids", "group.args", "scheme", 
                 "allowed.scales", "disallowed.scales", "panel.scales",
                 "reset.xylims", "load.lists", "lim.borders", "x.elements", 
                 "zcase.ids", "zcase.args", "zcase.zlim", "z.rowsum.lim")
-    ignore <- unique(ignore, loa.settings$common.args)
+    ignore <- unique(c(ignore, loa.settings$common.args))
 
     temp <- listUpdate(ans$panel.args.common, list(loa.settings = loa.settings, 
                                         ignore = ignore))
@@ -370,6 +370,13 @@ panelPal <- function(ans, panel = NULL, preprocess = FALSE,
 #could some of this be done at top?
 #in checks?
 
+##new bit to allow functions
+    if(is.function(reset.xylims)){
+        ans <- reset.xylims(ans)
+        reset.xylims <- "no.action"
+    }
+    
+
 ##new
     if(is.logical(reset.xylims)){
         reset.xylims <- if(reset.xylims) "refit.xylims" else "no.action" 
@@ -428,12 +435,17 @@ panelPal <- function(ans, panel = NULL, preprocess = FALSE,
 #compare this and new bit and see if 
 #complexity is needed
 
+
     #get names of elements in panel.args[[1]] that are numeric
     ranges <- sapply(names(ans$panel.args[[1]]), 
                         function(x) is.numeric(ans$panel.args[[1]][[x]]))
     ranges <- names(ans$panel.args[[1]])[ranges]
 
     #remove common names 
+
+#need to pull out allowed.scales
+#may need to check x/y handling here
+
     ranges <- ranges[!ranges %in% c("x", "y", "subscripts")]
 
     #remove elements for which lims are set in panel.args.common
@@ -456,6 +468,10 @@ panelPal <- function(ans, panel = NULL, preprocess = FALSE,
     ranges <- ans$panel.args.common$group.elements
     temp <- gsub("lim$", "", grep("lim$", names(ans$panel.args.common), value=T))
     ranges <- ranges[!ranges %in% temp]
+
+#need to pull out allowed.scales
+#may need to check x/y handling here
+
     ranges <- ranges[!ranges %in% c("x", "y", "subscripts")]
 
     if(length(ranges)>0){
@@ -466,6 +482,12 @@ panelPal <- function(ans, panel = NULL, preprocess = FALSE,
         ans$panel.args.common <- listUpdate(ans$panel.args.common, temp)    
     }
 
+
+#current allowed.scales fix
+    if("allowed.scales" %in% names(ans$panel.args.common))
+        ans$panel.args.common <- ans$panel.args.common[!names(ans$panel.args.common) %in% ans$panel.args.common$allowed.scales]
+    
+
 ##############
 #new
 ##############
